@@ -30,7 +30,6 @@ class SQL :
 
     MYSQL = 'mysql'
     POSTGRESQL = 'postgresql'
-    SQLITE = 'sqlite'
     SQLITE3 = 'sqlite3'
     
     clients = 'SELECT Client.Name,ClientId FROM Client'
@@ -76,21 +75,6 @@ class SQL :
     StartFile INTEGER,
     VolSessionId INTEGER,
     VolSessionTime INTEGER)
-    ''',
-        
-        SQLITE: '''
-    CREATE TEMPORARY TABLE temp (
-    JobId INTEGER UNSIGNED NOT NULL,
-    JobTDate BIGINT UNSIGNED,
-    ClientId INTEGER UNSIGNED,
-    Level CHAR,
-    JobFiles INTEGER UNSIGNED,
-    JobBytes BIGINT UNSIGNED,
-    StartTime TEXT,
-    VolumeName TEXT,
-    StartFile INTEGER UNSIGNED,
-    VolSessionId INTEGER UNSIGNED,
-    VolSessionTime INTEGER UNSIGNED)
     ''',
         
         SQLITE3: '''
@@ -119,12 +103,6 @@ class SQL :
     CREATE TEMPORARY TABLE temp1 (
     JobId INTEGER NOT NULL,
     JobTDate BIGINT)
-    ''',
-        
-        SQLITE: '''
-    CREATE TEMPORARY TABLE temp1 (
-    JobId INTEGER UNSIGNED NOT NULL,
-    JobTDate BIGINT UNSIGNED)
     ''',
         
         SQLITE3: '''
@@ -281,32 +259,6 @@ class SQL :
         -- dummy comment for chomping extra parameter: %s
      ''',
         
-        SQLITE: '''
-     SELECT FileId, Job.JobId AS JobId, FileIndex, File.PathId AS PathId, 
-            File.FilenameId AS FilenameId, LStat, MD5 
-     FROM Job, File, ( 
-         SELECT MAX(JobTDate) AS JobTDate, PathId, FilenameId 
-           FROM ( 
-             SELECT JobTDate, PathId, FilenameId 
-               FROM File JOIN Job USING (JobId) 
-              WHERE File.JobId IN (%s) 
-               UNION ALL 
-             SELECT JobTDate, PathId, FilenameId 
-               FROM BaseFiles 
-                    JOIN File USING (FileId) 
-                    JOIN Job  ON    (BaseJobId = Job.JobId) 
-              WHERE BaseFiles.JobId IN (%s) 
-            ) AS tmp GROUP BY PathId, FilenameId 
-         ) AS T1 
-     WHERE (Job.JobId IN ( 
-            SELECT DISTINCT BaseJobId FROM BaseFiles WHERE JobId IN (%s)) 
-            OR Job.JobId IN (%s)) 
-       AND T1.JobTDate = Job.JobTDate 
-       AND Job.JobId = File.JobId 
-       AND T1.PathId = File.PathId 
-       AND T1.FilenameId = File.FilenameId
-     ''',
-        
         SQLITE3: '''
      SELECT FileId, Job.JobId AS JobId, FileIndex, File.PathId AS PathId, 
             File.FilenameId AS FilenameId, LStat, MD5 
@@ -343,7 +295,7 @@ class SQL :
 
     volumes = '''
     SELECT JobMedia.JobId,VolumeName,MediaType,FirstIndex,LastIndex,StartFile,
-    JobMedia.EndFile,StartBlock,JobMedia.EndBlock,Copy,
+    JobMedia.EndFile,StartBlock,JobMedia.EndBlock,
     Slot,StorageId,InChanger
      FROM JobMedia,Media WHERE JobMedia.JobId IN (%s)
      AND JobMedia.MediaId=Media.MediaId ORDER BY JobMedia.JobId,VolIndex,JobMediaId
